@@ -3,6 +3,4 @@ Main package for texasholdem
 """
 
 from texasholdem.card import *
-from texasholdem.evaluator import *
 from texasholdem.game import *
-from texasholdem.gui import *
