@@ -61,7 +61,7 @@ class LookupTable:
         MAX_THREE_OF_A_KIND: 6,
         MAX_TWO_PAIR: 7,
         MAX_PAIR: 8,
-        MAX_HIGH_CARD: 9
+        MAX_HIGH_CARD: 9,
     }
 
     RANK_CLASS_TO_STRING = {
@@ -73,7 +73,7 @@ class LookupTable:
         6: "Three of a Kind",
         7: "Two Pair",
         8: "Pair",
-        9: "High card"
+        9: "High card",
     }
 
     def __init__(self):
@@ -106,13 +106,13 @@ class LookupTable:
             124,  # int('0b1111100', 2),
             62,  # int('0b111110', 2),
             31,  # int('0b11111', 2),
-            4111  # int('0b1000000001111', 2) # 5 high
+            4111,  # int('0b1000000001111', 2) # 5 high
         ]
 
         # now we'll dynamically generate all the other
         # flushes (including straight flushes)
         flushes = []
-        gen = LookupTable._get_lexographically_next_bit_sequence(int('0b11111', 2))
+        gen = LookupTable._get_lexographically_next_bit_sequence(int("0b11111", 2))
 
         # 1277 = number of high card
         # 1277 + len(str_flushes) is number of hands with all card unique rank
@@ -224,7 +224,9 @@ class LookupTable:
 
             for kickers in itertools.combinations(kickers, 2):
                 card1, card2 = kickers
-                product = Card.PRIMES[b_rank] ** 3 * Card.PRIMES[card1] * Card.PRIMES[card2]
+                product = (
+                    Card.PRIMES[b_rank] ** 3 * Card.PRIMES[card1] * Card.PRIMES[card2]
+                )
                 self.unsuited_lookup[product] = rank
                 rank += 1
 
@@ -238,7 +240,11 @@ class LookupTable:
             kickers.remove(pair1)
             kickers.remove(pair2)
             for kicker in kickers:
-                product = Card.PRIMES[pair1] ** 2 * Card.PRIMES[pair2] ** 2 * Card.PRIMES[kicker]
+                product = (
+                    Card.PRIMES[pair1] ** 2
+                    * Card.PRIMES[pair2] ** 2
+                    * Card.PRIMES[kicker]
+                )
                 self.unsuited_lookup[product] = rank
                 rank += 1
 
@@ -253,8 +259,12 @@ class LookupTable:
 
             for kickers in itertools.combinations(kickers, 3):
                 kicker1, kicker2, kicker3 = kickers
-                product = Card.PRIMES[pairrank] ** 2 * Card.PRIMES[kicker1] \
-                    * Card.PRIMES[kicker2] * Card.PRIMES[kicker3]
+                product = (
+                    Card.PRIMES[pairrank] ** 2
+                    * Card.PRIMES[kicker1]
+                    * Card.PRIMES[kicker2]
+                    * Card.PRIMES[kicker3]
+                )
                 self.unsuited_lookup[product] = rank
                 rank += 1
 
@@ -272,7 +282,9 @@ class LookupTable:
         yield lexo_next
         while True:
             xbits = (lexo_next | (lexo_next - 1)) + 1
-            lexo_next = xbits | ((((xbits & -xbits) // (lexo_next & -lexo_next)) >> 1) - 1)
+            lexo_next = xbits | (
+                (((xbits & -xbits) // (lexo_next & -lexo_next)) >> 1) - 1
+            )
             yield lexo_next
 
 
